MatchModel class

Convenience model representing a match in a tournament (can be used as a default).

Constructors

MatchModel({required int id, required String label, required String table, required String time, required Player player1, required Player player2, required int score1, required int score2})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hasWinner bool
no setter
id int
final
label String
final
player1 Player
final
player2 Player
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score1 int
final
score2 int
final
table String
final
time String
final
winner Player
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited