read_map_matches library

Classes

AnimatedTournamentBracket<T>
A premium, highly customizable generic tournament bracket widget supporting any match model T.
BracketPainter<T>
A high-performance CustomPainter that draws orthogonal victory-glow connecting lines between match cards of generic type T, dynamically morphing their coordinates in real time.
MatchModel
Convenience model representing a match in a tournament (can be used as a default).
Player
Convenience model representing a player in a tournament (can be used as a default).