AnimatedTournamentBracket<T> class
A premium, highly customizable generic tournament bracket widget supporting any match model T.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AnimatedTournamentBracket
Constructors
-
AnimatedTournamentBracket({Key? key, required List<
List< branch1Rounds, required T grandFinal, required Widget itemBuilder(BuildContext context, T match), List<T> >List< ? branch2Rounds, List<T> >String> ? roundTitles, Widget tabBuilder(BuildContext context, int index, bool isSelected)?, Widget tabBarBuilder(BuildContext context, double pageOffset, int activeRound, void onTabTap(int index))?, bool hasWinner(T match)?, String getWinnerName(T match)?, String getPlayer1Name(T match)?, String getPlayer2Name(T match)?, String upperBranchLabel = 'NHÁNH TRÊN', String lowerBranchLabel = 'NHÁNH DƯỚI', Color primaryColor = const Color(0xFF0066FF), Color secondaryColor = const Color(0xFF00E5FF), Color backgroundColor = const Color(0xFF070B19), Color surfaceColor = const Color(0xFF131A30), Color accentColor = const Color(0xFFFFB300), Color defaultLineColor = const Color(0x33FFFFFF), double connectorRadius = 8.0}) -
const
Properties
- accentColor → Color
-
final
- backgroundColor → Color
-
final
-
branch1Rounds
→ List<
List< T> > -
Rounds list for the first branch (Upper).
final
-
branch2Rounds
→ List<
List< ?T> > -
Rounds list for the second branch (Lower, optional).
final
- connectorRadius → double
-
The radius for connection line corners. Defaults to 8.0 (subtle).
final
- defaultLineColor → Color
-
final
- getPlayer1Name → String Function(T match)?
-
final
- getPlayer2Name → String Function(T match)?
-
final
- getWinnerName → String Function(T match)?
-
final
- grandFinal → T
-
The final championship match that connects the branch winners.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasWinner → bool Function(T match)?
-
Optional connection line highlighting callbacks.
final
- itemBuilder → Widget Function(BuildContext context, T match)
-
Custom Card layout builder. EXTREMELY powerful for complete custom interfaces.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lowerBranchLabel → String
-
final
- primaryColor → Color
-
Design system theme colors
final
-
roundTitles
→ List<
String> ? -
Optional custom round titles.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryColor → Color
-
final
- surfaceColor → Color
-
final
- tabBarBuilder → Widget Function(BuildContext context, double pageOffset, int activeRound, void onTabTap(int index))?
-
A builder callback to fully override and customize the entire Round Tab Bar.
Receives:
final
- tabBuilder → Widget Function(BuildContext context, int index, bool isSelected)?
-
Custom Tab item builder. Allows developers to fully customize the round tab labels!
final
- upperBranchLabel → String
-
Branch labels
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AnimatedTournamentBracket< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited