MatchModel class
Convenience model representing a match in a tournament (can be used as a default).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasWinner → bool
-
no setter
- id → int
-
final
- label → String
-
final
- player1 → Player
-
final
- player2 → Player
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- score1 → int
-
final
- score2 → int
-
final
- table → String
-
final
- time → String
-
final
- winner → Player
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited