menu
read_map_matches package
documentation
read_map_matches.dart
read_map_matches.dart
dark_mode
light_mode
read_map_matches
library
Classes
AnimatedTournamentBracket
<
T
>
A premium, highly customizable generic tournament bracket widget supporting any match model T.
BracketPainter
<
T
>
A high-performance CustomPainter that draws orthogonal victory-glow connecting lines between match cards of generic type T, dynamically morphing their coordinates in real time.
MatchModel
Convenience model representing a match in a tournament (can be used as a default).
Player
Convenience model representing a player in a tournament (can be used as a default).
read_map_matches package
documentation
read_map_matches.dart
read_map_matches
package
Libraries
animated_tournament_bracket
bracket_painter
read_map_matches
read_map_matches library